.. _tutorials page:

#########
Tutorials
#########

MusicBox offers a series of tutorial notebooks that guide users from simple workflows to more advanced simulations, available in multiple formats below for ease of access.

Interactive Notebooks
----------------------
The MusicBox repository utilizes `Binder <https://mybinder.readthedocs.io/en/latest/index.html#>`_ to allow users to interact with the tutorial notebooks on a `JupyterHub <https://jupyter.org/hub>`_.
Each of the links below will open a JupyterHub set up with all necessary dependencies to run each tutorial:

- `Basic MusicBox Workflow <https://mybinder.org/v2/gh/NCAR/music-box/main?urlpath=lab%2Ftree%2Ftutorials%2F1.%20basic_workflow.ipynb>`_
- `Overriding Mechanisms <https://mybinder.org/v2/gh/NCAR/music-box/main?urlpath=lab%2Ftree%2Ftutorials%2F2.%20override_mechanism.ipynb>`_
- `Loading Custom Box Models <https://mybinder.org/v2/gh/NCAR/music-box/main?urlpath=lab%2Ftree%2Ftutorials%2F3.%20loading_custom_box_models.ipynb>`_
- `Machine Learning <https://mybinder.org/v2/gh/NCAR/music-box/main?urlpath=lab%2Ftree%2Ftutorials%2F4.%20machine_learning.ipynb>`_
- `Solving with GPUs <https://mybinder.org/v2/gh/NCAR/music-box/main?urlpath=lab%2Ftree%2Ftutorials%2F5.%20gpu_solver.ipynb>`_

GitHub
--------
For users that wish to directly download local copies of the tutorial notebooks, they are each made available on our GitHub within the `tutorials <https://github.com/NCAR/music-box/tree/main/tutorials>`_ folder. Each notebook is also linked below:

- `Basic MusicBox Workflow <https://github.com/NCAR/music-box/blob/main/tutorials/1.%20basic_workflow.ipynb>`_
- `Overriding Mechanisms <https://github.com/NCAR/music-box/blob/main/tutorials/2.%20override_mechanism.ipynb>`_
- `Loading Custom Box Models <https://github.com/NCAR/music-box/blob/main/tutorials/3.%20loading_custom_box_models.ipynb>`_
- `Machine Learning <https://github.com/NCAR/music-box/blob/main/tutorials/4.%20machine_learning.ipynb>`_
- `Solving with GPUs <https://github.com/NCAR/music-box/blob/main/tutorials/5.%20gpu_solver.ipynb>`_


Web View
---------
The tutorial notebooks are also included here in the documentation for convenient online browsing.

.. toctree::
   :maxdepth: 1

   1. basic_workflow
   2. override_mechanism
   3. loading_custom_box_models
   4. machine_learning
   5. gpu_solver